@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '5.20210320';
+$CPAN::Perl::Releases::VERSION = '5.20251120';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -58,7 +58,6 @@ our $data =
 "5.11.1" => { id => 'JESSE' },
 "5.11.2" => { id => 'LBROCARD' },
 "5.11.3" => { id => 'JESSE' },
-"5.11.4" => { id => 'RJBS' },
 "5.11.5" => { id => 'SHAY' },
 "5.12.0" => { id => 'JESSE' },
 "5.12.1" => { id => 'JESSE' },
@@ -67,7 +66,6 @@ our $data =
 "5.12.4" => { id => 'LBROCARD' },
 "5.12.5" => { id => 'DOM' },
 "5.13.0" => { id => 'LBROCARD' },
-"5.13.1" => { id => 'RJBS' },
 "5.13.2" => { id => 'MSTROUT' },
 "5.13.3" => { id => 'DAGOLDEN' },
 "5.13.4" => { id => 'FLORA' },
@@ -88,13 +86,11 @@ our $data =
 "5.14.4" => { id => 'DAPM' },
 "5.15.0" => { id => 'DAGOLDEN' },
 "5.15.1" => { id => 'ZEFRAM' },
-"5.15.2" => { id => 'RJBS' },
 "5.15.3" => { id => 'STEVAN' },
 "5.15.4" => { id => 'FLORA' },
 "5.15.5" => { id => 'SHAY' },
 "5.15.6" => { id => 'DROLSKY' },
 "5.15.7" => { id => 'BINGOS' },
-"5.15.8" => { id => 'CORION' },
 "5.15.9" => { id => 'ABIGAIL' },
 "5.16.0" => { id => 'RJBS' },
 "5.16.1" => { id => 'RJBS' },
@@ -106,29 +102,22 @@ our $data =
 "5.17.3" => { id => 'SHAY' },
 "5.17.4" => { id => 'FLORA' },
 "5.17.5" => { id => 'FLORA' },
-"5.17.6" => { id => 'RJBS' },
 "5.17.7" => { id => 'DROLSKY' },
 "5.17.8" => { id => 'ARC' },
 "5.17.9" => { id => 'BINGOS' },
-"5.17.10" => { id => 'CORION' },
-"5.17.11" => { id => 'RJBS' },
 "5.18.0" => { id => 'RJBS' },
 "5.18.1" => { id => 'RJBS' },
-"5.19.0" => { id => 'RJBS' },
 "5.19.1" => { id => 'DAGOLDEN' },
-"5.19.2" => { id => 'ARISTOTLE' },
 "5.19.3" => { id => 'SHAY' },
 "5.19.4" => { id => 'SHAY' },
 "5.19.5" => { id => 'SHAY' },
 "5.19.6" => { id => 'BINGOS' },
 "5.19.7" => { id => 'ABIGAIL' },
 "5.18.2" => { id => 'RJBS' },
-"5.19.8" => { id => 'RJBS' },
 "5.19.9" => { id => 'TONYC' },
 "5.19.10" => { id => 'ARC' },
 "5.19.11" => { id => 'SHAY' },
 "5.20.0" => { id => 'RJBS' },
-"5.21.0" => { id => 'RJBS' },
 "5.21.1" => { id => 'WOLFSAGE' },
 "5.21.2" => { id => 'ABIGAIL' },
 "5.21.3" => { id => 'PCM' },
@@ -140,14 +129,12 @@ our $data =
 "5.18.4" => { id => 'RJBS' },
 "5.21.5" => { id => 'ABIGAIL' },
 "5.21.6" => { id => 'BINGOS' },
-"5.21.7" => { id => 'CORION' },
 "5.21.8" => { id => 'WOLFSAGE' },
 "5.20.2-RC1" => { id => 'SHAY' },
 "5.20.2" => { id => 'SHAY' },
 "5.21.10" => { id => 'SHAY' },
 "5.21.11" => { id => 'SHAY' },
 "5.22.0" => { id => 'RJBS' },
-"5.23.0" => { id => 'RJBS' },
 "5.23.1" => { id => 'WOLFSAGE' },
 "5.23.2" => { id => 'WOLFSAGE' },
 "5.20.3-RC1" => { id => 'SHAY' },
@@ -165,14 +152,8 @@ our $data =
 "5.23.7" => { id => 'STEVAN' },
 "5.23.9" => { id => 'ABIGAIL' },
 "5.22.2-RC1" => { id => 'SHAY' },
-"5.24.0-RC1" => { id => 'RJBS' },
-"5.24.0-RC2" => { id => 'RJBS' },
-"5.24.0-RC3" => { id => 'RJBS' },
 "5.22.2" => { id => 'SHAY' },
-"5.24.0-RC4" => { id => 'RJBS' },
-"5.24.0-RC5" => { id => 'RJBS' },
 "5.24.0" => { id => 'RJBS' },
-"5.25.0" => { id => 'RJBS' },
 "5.25.2" => { id => 'WOLFSAGE' },
 "5.22.3-RC1" => { id => 'SHAY' },
 "5.24.1-RC1" => { id => 'SHAY' },
@@ -188,7 +169,7 @@ our $data =
 "5.25.6" => { id => 'ARC' },
 "5.25.7" => { id => 'EXODIST' },
 "5.22.3-RC5" => { id => 'SHAY' },
-"5.24.1-RC5" => { id => 'SHAY' },
+"5.24.1-RC5" => { id => 'SHAY', noxz => 1 },
 "5.22.3" => { id => 'SHAY' },
 "5.24.1" => { id => 'SHAY' },
 "5.25.9" => { id => 'ABIGAIL' },
@@ -243,7 +224,6 @@ our $data =
 "5.31.0" => { id => 'XSAWYERX' },
 "5.31.1" => { id => 'ETHER' },
 "5.31.2" => { id => 'SHAY' },
-"5.31.3" => { id => 'TOMHUKINS' },
 "5.31.4" => { id => 'CORION' },
 "5.31.5" => { id => 'SHAY' },
 "5.30.1-RC1" => { id => 'SHAY' },
@@ -267,13 +247,100 @@ our $data =
 "5.33.1" => { id => 'ETHER' },
 "5.33.2" => { id => 'XSAWYERX' },
 "5.33.3" => { id => 'SHAY' },
-"5.33.4" => { id => 'TOMHUKINS' },
 "5.33.5" => { id => 'CORION' },
 "5.32.1-RC1" => { id => 'SHAY' },
 "5.33.6" => { id => 'HYDAHY' },
 "5.32.1" => { id => 'SHAY' },
 "5.33.7" => { id => 'RENEEB' },
 "5.33.8" => { id => 'ATOOMIC' },
+"5.33.9" => { id => 'TODDR' },
+"5.34.0-RC1" => { id => 'XSAWYERX' },
+"5.34.0-RC2" => { id => 'XSAWYERX' },
+"5.34.0" => { id => 'XSAWYERX' },
+"5.35.0" => { id => 'RJBS' },
+"5.35.1" => { id => 'CORION' },
+"5.35.3" => { id => 'ETHER' },
+"5.35.4" => { id => 'WOLFSAGE' },
+"5.35.5" => { id => 'LEONT' },
+"5.35.6" => { id => 'HYDAHY' },
+"5.35.8" => { id => 'ATOOMIC' },
+"5.35.9" => { id => 'RENEEB' },
+"5.34.1-RC1" => { id => 'SHAY' },
+"5.34.1-RC2" => { id => 'SHAY' },
+"5.34.1" => { id => 'SHAY' },
+"5.35.10" => { id => 'XSAWYERX' },
+"5.35.11" => { id => 'SHAY' },
+"5.36.0-RC2" => { id => 'RJBS' },
+"5.36.0-RC3" => { id => 'RJBS' },
+"5.36.0" => { id => 'RJBS' },
+"5.37.0" => { id => 'RJBS' },
+"5.37.1" => { id => 'WOLFSAGE' },
+"5.37.2" => { id => 'ATOOMIC' },
+"5.37.4" => { id => 'ETHER' },
+"5.37.5" => { id => 'TODDR' },
+"5.37.6" => { id => 'CORION' },
+"5.37.7" => { id => 'HYDAHY' },
+"5.37.8" => { id => 'RENEEB' },
+"5.37.9" => { id => 'ETHER' },
+"5.37.10" => { id => 'YVES' },
+"5.36.1-RC1" => { id => 'SHAY' },
+"5.36.1-RC2" => { id => 'SHAY' },
+"5.36.1-RC3" => { id => 'SHAY' },
+"5.37.11" => { id => 'SHAY' },
+"5.36.1" => { id => 'SHAY' },
+"5.38.0-RC1" => { id => 'RJBS' },
+"5.38.0-RC2" => { id => 'RJBS' },
+"5.38.0" => { id => 'RJBS' },
+"5.39.1" => { id => 'SHAY' },
+"5.39.2" => { id => 'PEVANS' },
+"5.39.3" => { id => 'WOLFSAGE' },
+"5.39.4" => { id => 'HAARG' },
+"5.39.5" => { id => 'ETHER' },
+"5.34.3" => { id => 'PEVANS' },
+"5.36.3" => { id => 'PEVANS' },
+"5.38.2" => { id => 'PEVANS' },
+"5.39.6" => { id => 'BOOK' },
+"5.39.7" => { id => 'CORION' },
+"5.39.8" => { id => 'RENEEB' },
+"5.39.9" => { id => 'PEVANS' },
+"5.39.10" => { id => 'PEVANS' },
+"5.40.0-RC1" => { id => 'HAARG' },
+"5.40.0-RC2" => { id => 'HAARG' },
+"5.40.0" => { id => 'HAARG' },
+"5.41.1" => { id => 'BOOK' },
+"5.41.2" => { id => 'ETHER' },
+"5.41.3" => { id => 'BOOK' },
+"5.41.4" => { id => 'CONTRA' },
+"5.41.5" => { id => 'HYDAHY' },
+"5.41.6" => { id => 'CONTRA' },
+"5.41.7" => { id => 'CORION' },
+"5.38.3-RC1" => { id => 'SHAY' },
+"5.40.1-RC1" => { id => 'SHAY' },
+"5.38.3" => { id => 'SHAY' },
+"5.40.1" => { id => 'SHAY' },
+"5.41.8" => { id => 'SHAY' },
+"5.41.9" => { id => 'HYDAHY' },
+"5.41.10" => { id => 'MAUKE' },
+"5.38.4-RC1" => { id => 'SHAY' },
+"5.40.2-RC1" => { id => 'SHAY' },
+"5.38.4" => { id => 'SHAY' },
+"5.40.2" => { id => 'SHAY' },
+"5.41.11" => { id => 'ETHER' },
+"5.41.12" => { id => 'ETHER' },
+"5.41.13" => { id => 'BOOK' },
+"5.42.0-RC1" => { id => 'CONTRA' },
+"5.42.0-RC2" => { id => 'CONTRA' },
+"5.42.0-RC3" => { id => 'CONTRA' },
+"5.42.0" => { id => 'BOOK' },
+"5.43.1" => { id => 'HYDAHY' },
+"5.38.5-RC1" => { id => 'SHAY' },
+"5.40.3-RC1" => { id => 'SHAY' },
+"5.38.5" => { id => 'SHAY' },
+"5.40.3" => { id => 'SHAY' },
+"5.43.2" => { id => 'ETHER' },
+"5.43.3" => { id => 'CONTRA' },
+"5.43.4" => { id => 'EHERMAN' },
+"5.43.5" => { id => 'CONTRA' },
 };
 
 sub perl_tarballs {
@@ -304,6 +371,7 @@ sub perl_tarballs {
   $foo->{'tar.gz'} = "$path/$perl.tar.gz" unless $onlybz2;
   $foo->{'tar.bz2'} = "$path/$perl.tar.bz2" unless $onlygz || $lvers > 5.027005;
   $foo->{'tar.xz'} = "$path/$perl.tar.xz" if $lvers > 5.021005 && !$noxz;
+  delete $foo->{'tar.bz2'} if $pumpkin eq 'SHAY' && $lvers < 5.028000;
   $cache->{ $vers } = $foo;
   return { %$foo };
 }
@@ -342,7 +410,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 5.20210320
+version 5.20251120
 
 =head1 SYNOPSIS
 
@@ -407,7 +475,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Chris Williams.
+This software is copyright (c) 2025 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
